@@ -1,12 +1,6 @@
-/* LICENSE BEGIN
-    This file is part of the SixtyFPS Project -- https://sixtyfps.io
-    Copyright (c) 2021 Olivier Goffart <olivier.goffart@sixtyfps.io>
-    Copyright (c) 2021 Simon Hausmann <simon.hausmann@sixtyfps.io>
+// Copyright © SixtyFPS GmbH <info@sixtyfps.io>
+// SPDX-License-Identifier: (GPL-3.0-only OR LicenseRef-SixtyFPS-commercial)
 
-    SPDX-License-Identifier: GPL-3.0-only
-    This file is also available under commercial licensing terms.
-    Please contact info@sixtyfps.io for more information.
-LICENSE END */
 use crate::{api::Value, dynamic_type, eval};
 
 use core::convert::TryInto;
@@ -184,6 +178,7 @@ impl Component for ErasedComponentBox {
 
 sixtyfps_corelib::ComponentVTable_static!(static COMPONENT_BOX_VT for ErasedComponentBox);
 
+#[derive(Default)]
 pub(crate) struct ComponentExtraData {
     pub(crate) globals: HashMap<String, Pin<Rc<dyn crate::global_component::GlobalComponent>>>,
     pub(crate) self_weak:
@@ -192,16 +187,6 @@ pub(crate) struct ComponentExtraData {
     pub(crate) embedded_file_resources: HashMap<usize, String>,
 }
 
-impl Default for ComponentExtraData {
-    fn default() -> Self {
-        Self {
-            globals: HashMap::new(),
-            self_weak: Default::default(),
-            embedded_file_resources: Default::default(),
-        }
-    }
-}
-
 struct ErasedRepeaterWithinComponent<'id>(RepeaterWithinComponent<'id, 'static>);
 impl<'id, 'sub_id> From<RepeaterWithinComponent<'id, 'sub_id>>
     for ErasedRepeaterWithinComponent<'id>
@@ -583,7 +568,7 @@ impl<'id> ComponentDescription<'id> {
         // Safety: we just verified that the component has the right vtable
         let c = unsafe { InstanceRef::from_pin_ref(component, guard) };
         let extra_data = c.component_type.extra_data_offset.apply(c.instance.get_ref());
-        extra_data.globals.get(global_name).map(|g| g.clone()).ok_or(())
+        extra_data.globals.get(global_name).cloned().ok_or(())
     }
 }
 
@@ -851,7 +836,7 @@ pub(crate) fn generate_component<'id>(
             _children_offset: u32,
             _component_state: &Self::SubComponentState,
         ) -> Self::SubComponentState {
-            ()
+            /* nothing to do */
         }
 
         fn enter_component_children(
@@ -950,6 +935,7 @@ pub(crate) fn generate_component<'id>(
                 "TextOverflow" => property_info::<sixtyfps_corelib::items::TextOverflow>(),
                 "ImageFit" => property_info::<sixtyfps_corelib::items::ImageFit>(),
                 "FillRule" => property_info::<sixtyfps_corelib::items::FillRule>(),
+                "MouseCursor" => property_info::<sixtyfps_corelib::items::MouseCursor>(),
                 "StandardButtonKind" => {
                     property_info::<sixtyfps_corelib::items::StandardButtonKind>()
                 }
@@ -1130,14 +1116,13 @@ pub fn instantiate(
         extra_data.globals = component_type
             .compiled_globals
             .iter()
-            .map(|g| {
+            .flat_map(|g| {
                 let (_, instance) = crate::global_component::instantiate(g);
                 g.names()
                     .iter()
                     .map(|name| (crate::normalize_identifier(name).to_string(), instance.clone()))
                     .collect::<Vec<_>>()
             })
-            .flatten()
             .collect();
 
         extra_data.embedded_file_resources = component_type
