@@ -1,12 +1,5 @@
-/* LICENSE BEGIN
-    This file is part of the SixtyFPS Project -- https://sixtyfps.io
-    Copyright (c) 2021 Olivier Goffart <olivier.goffart@sixtyfps.io>
-    Copyright (c) 2021 Simon Hausmann <simon.hausmann@sixtyfps.io>
-
-    SPDX-License-Identifier: GPL-3.0-only
-    This file is also available under commercial licensing terms.
-    Please contact info@sixtyfps.io for more information.
-LICENSE END */
+// Copyright © SixtyFPS GmbH <info@sixtyfps.io>
+// SPDX-License-Identifier: (GPL-3.0-only OR LicenseRef-SixtyFPS-commercial)
 
 use core::pin::Pin;
 use std::collections::BTreeMap;
@@ -105,10 +98,10 @@ pub fn instantiate(description: &CompiledGlobal) -> (String, Pin<Rc<dyn GlobalCo
                 }
             }
             impl Helper for () {}
-            impl<T: rtti::BuiltinItem + Default + 'static, Next: Helper> Helper for (T, Next) {
+            impl<T: rtti::BuiltinGlobal + 'static, Next: Helper> Helper for (T, Next) {
                 fn instantiate(name: &str) -> Pin<Rc<dyn GlobalComponent>> {
                     if name == T::name() {
-                        Rc::pin(T::default())
+                        T::new()
                     } else {
                         Next::instantiate(name)
                     }
@@ -139,7 +132,7 @@ pub fn instantiate(description: &CompiledGlobal) -> (String, Pin<Rc<dyn GlobalCo
 }
 
 /// For the global components, we don't use the dynamic_type optimization,
-/// and we don't try to to optimize the property to their real type
+/// and we don't try to optimize the property to their real type
 pub struct GlobalComponentInstance(vtable::VRc<ComponentVTable, ErasedComponentBox>);
 
 impl GlobalComponent for GlobalComponentInstance {
